@@ -13,11 +13,14 @@
 
 static socket_t dtmf_log_sock;
 
-void dtmf_init(void) {
+bool dtmf_init(void) {
 	ilog(LOG_DEBUG, "log dtmf over ng %d", rtpe_config.dtmf_via_ng);
 	ilog(LOG_DEBUG, "no log injected dtmf %d", rtpe_config.dtmf_no_log_injects);
-	if (open_v46_socket(&dtmf_log_sock, SOCK_DGRAM))
+	if (open_v46_socket(&dtmf_log_sock, SOCK_DGRAM)) {
 		ilog(LOG_ERR, "Failed to open/connect DTMF logging socket: %s", strerror(errno));
+		return false;
+	}
+	return true;
 }
 
 static unsigned int dtmf_volume_from_dsp(int vol) {
@@ -139,14 +142,21 @@ static void dtmf_end_event(struct call_media *media, unsigned int event, unsigne
 	if (!clockrate)
 		clockrate = 8000;
 
-	struct dtmf_event *ev = g_slice_alloc0(sizeof(*ev));
-	*ev = (struct dtmf_event) { .code = 0, .ts = ts, .volume = 0 };
-	g_queue_push_tail(&media->dtmf_recv, ev);
+	// don't add to recv list when it's injected, it can cause the list TS's to be out
+	// of order breaking the dtmf-security and letting the generated PCM frames through
+	if (!injected) {
+		struct dtmf_event *ev = g_slice_alloc0(sizeof(*ev));
+		*ev = (struct dtmf_event) { .code = 0, .ts = ts, .volume = 0 };
+		g_queue_push_tail(&media->dtmf_recv, ev);
+	}
 
-	ev = g_slice_alloc0(sizeof(*ev));
-	*ev = (struct dtmf_event) { .code = 0, .ts = ts + media->monologue->dtmf_delay * clockrate / 1000,
-		.volume = 0, .block_dtmf = media->monologue->block_dtmf };
-	g_queue_push_tail(&media->dtmf_send, ev);
+	// only add to send list if injected, a delayed send, or not being blocked
+	if (injected || !media->monologue->block_dtmf || media->monologue->dtmf_delay) {
+		struct dtmf_event *ev = g_slice_alloc0(sizeof(*ev));
+		*ev = (struct dtmf_event) { .code = 0, .ts = ts + media->monologue->dtmf_delay * clockrate / 1000,
+			.volume = 0, .block_dtmf = media->monologue->block_dtmf };
+		g_queue_push_tail(&media->dtmf_send, ev);
+	}
 
 	if (!dtmf_do_logging(media->call, injected))
 		return;
@@ -285,7 +295,7 @@ static void dtmf_check_trigger(struct call_media *media, char event, uint64_t ts
 }
 
 // media->dtmf_lock must be held
-static void dtmf_code_event(struct call_media *media, char event, uint64_t ts, int clockrate, int volume) {
+static void dtmf_code_event(struct call_media *media, char event, uint64_t ts, int clockrate, int volume, bool injected) {
 	struct dtmf_event *ev = g_queue_peek_tail(&media->dtmf_recv);
 	if (ev && ev->code == event)
 		return;
@@ -295,16 +305,23 @@ static void dtmf_code_event(struct call_media *media, char event, uint64_t ts, i
 	// check trigger before setting new dtmf_start
 	dtmf_check_trigger(media, event, ts, clockrate);
 
-	ev = g_slice_alloc0(sizeof(*ev));
-	*ev = (struct dtmf_event) { .code = event, .ts = ts, .volume = volume,
-		.rand_code = '0' + (ssl_random() % 10), .index = media->dtmf_count };
-	g_queue_push_tail(&media->dtmf_recv, ev);
+	// don't add to recv list when it's injected, it can cause the list TS's to be out
+	// of order breaking the dtmf-security and letting the generated PCM frames through
+	if (!injected) {
+		ev = g_slice_alloc0(sizeof(*ev));
+		*ev = (struct dtmf_event) { .code = event, .ts = ts, .volume = volume,
+			.rand_code = '0' + (ssl_random() % 10), .index = media->dtmf_count };
+		g_queue_push_tail(&media->dtmf_recv, ev);
+	}
 
-	ev = g_slice_alloc0(sizeof(*ev));
-	*ev = (struct dtmf_event) { .code = event, .ts = ts + media->monologue->dtmf_delay * clockrate / 1000,
-		.volume = volume,
-		.block_dtmf = media->monologue->block_dtmf };
-	g_queue_push_tail(&media->dtmf_send, ev);
+	// only add to send list if injected, a delayed send, or not being blocked
+	if (injected || !media->monologue->block_dtmf || media->monologue->dtmf_delay) {
+		ev = g_slice_alloc0(sizeof(*ev));
+		*ev = (struct dtmf_event) { .code = event, .ts = ts + media->monologue->dtmf_delay * clockrate / 1000,
+			.volume = volume,
+			.block_dtmf = media->monologue->block_dtmf };
+		g_queue_push_tail(&media->dtmf_send, ev);
+	}
 
 	media->dtmf_count++;
 }
@@ -369,7 +386,7 @@ int dtmf_event_packet(struct media_packet *mp, str *payload, int clockrate, uint
 			dtmf->event, dtmf->volume, dtmf->end, duration);
 
 	if (!dtmf->end) {
-		dtmf_code_event(mp->media, dtmf_code_to_char(dtmf->event), ts, clockrate, dtmf->volume);
+		dtmf_code_event(mp->media, dtmf_code_to_char(dtmf->event), ts, clockrate, dtmf->volume, false);
 		return 0;
 	}
 
@@ -421,7 +438,7 @@ void dtmf_dsp_event(const struct dtmf_event *new_event, struct dtmf_event *cur_e
 		int code = dtmf_code_from_char(new_event->code); // for validation
 		if (code != -1)
 			dtmf_code_event(media, (char) new_event->code, ts, clockrate,
-					dtmf_volume_from_dsp(new_event->volume));
+					dtmf_volume_from_dsp(new_event->volume), injected);
 	}
 }
 
@@ -433,8 +450,8 @@ void dtmf_event_free(void *e) {
 int dtmf_event_payload(str *buf, uint64_t *pts, uint64_t duration, struct dtmf_event *cur_event, GQueue *events) {
 	// do we have a relevant state change?
 	struct dtmf_event prev_event = *cur_event;
+	struct dtmf_event *ev = g_queue_peek_head(events);
 	while (events->length) {
-		struct dtmf_event *ev = g_queue_peek_head(events);
 		ilog(LOG_DEBUG, "Next DTMF event starts at %" PRIu64 ". PTS now %" PRIu64, ev->ts, *pts);
 		if (ev->ts > *pts)
 			break; // future event
@@ -444,6 +461,14 @@ int dtmf_event_payload(str *buf, uint64_t *pts, uint64_t duration, struct dtmf_e
 		g_queue_pop_head(events);
 		*cur_event = *ev;
 		dtmf_event_free(ev);
+		ev = g_queue_peek_head(events);
+		if (ev && ev->code == 0 && cur_event->ts < *pts) {
+			// if the start event ts was before *pts we need
+			// to adjust the end event_ts to ensure we're not shortening
+			// the event
+			ilog(LOG_DEBUG, "Delayed send of DTMF, adjusting end event_ts by %lu - %lu = %lu", *pts, cur_event->ts, *pts - cur_event->ts);
+			ev->ts += *pts - cur_event->ts;
+		}
 		cur_event->ts = *pts; // canonicalise start TS
 	}
 
@@ -647,13 +672,21 @@ const char *dtmf_inject(struct call_media *media, int code, int volume, int dura
 			ssrc_in->parent->h.ssrc);
 
 	// synthesise start and stop events
-	uint64_t num_samples = (uint64_t) duration * ch->dest_pt.clock_rate / 1000;
+	// the num_samples needs to be based on the the previous packet timestamp so we need to
+	// reduce it by one packets worth or we'll generate one too many packets than requested
+	uint64_t num_samples = (uint64_t) (duration - ch->dest_pt.ptime) * ch->dest_pt.clock_rate / 1000;
 	uint64_t start_pts = codec_encoder_pts(csh, ssrc_in);
+	// get the last event end time, and increase by the required pause
+	// conversely to the above, we need to add the last packet num samples to its TS before adding
+	// a pause so we dont generate one packet too few
+	// if that's later than start_pts, we need to adjust it
 	uint64_t last_end_pts = codec_last_dtmf_event(csh);
 	if (last_end_pts) {
-		// shift this new event past the end of the last event plus a pause
-		start_pts = last_end_pts + pause * ch->dest_pt.clock_rate / 1000;
+		last_end_pts += (pause + ch->dest_pt.ptime) * ch->dest_pt.clock_rate / 1000;
+		if (last_end_pts > start_pts)
+			start_pts = last_end_pts;
 	}
+
 	codec_add_dtmf_event(csh, dtmf_code_to_char(code), volume, start_pts, true);
 	codec_add_dtmf_event(csh, 0, 0, start_pts + num_samples, true);
 
