@@ -3,10 +3,9 @@
 
 #include "socket.h"
 #include "obj.h"
-#include "aux.h"
+#include "helpers.h"
 
 
-struct poller;
 struct obj;
 struct streambuf_callback;
 struct streambuf_stream;
@@ -16,7 +15,6 @@ typedef void (*streambuf_callback_t)(struct streambuf_stream *);
 
 struct streambuf_listener {
 	socket_t listener;
-	struct poller *poller;
 	mutex_t lock;
 	GHashTable *streams;
 };
@@ -32,13 +30,12 @@ struct streambuf_stream {
 
 };
 
-int tcp_listener_init(socket_t *, struct poller *p, const endpoint_t *, tcp_listener_callback_t, struct obj *);
+int tcp_listener_init(socket_t *, const endpoint_t *, tcp_listener_callback_t, struct obj *);
 
-int streambuf_listener_init(struct streambuf_listener *listener, struct poller *p, const endpoint_t *ep,
+int streambuf_listener_init(struct streambuf_listener *listener, const endpoint_t *ep,
 		streambuf_callback_t newconn_func,
 		streambuf_callback_t newdata_func,
 		streambuf_callback_t closed_func,
-		streambuf_callback_t timer_func,
 		struct obj *obj);
 void streambuf_listener_shutdown(struct streambuf_listener *);
 
